==> crisis-management-resources-v0.2-sources.jar: org/petalslink/officeofinfrastructure/OfficeOfInfrastructureEventProducer_WSOUIService.java <==
package org.petalslink.officeofinfrastructure;

import com.petalslink.wsn.service.wsnproducer.NotificationProducer;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.AbstractExchangeProcessor;
import org.petalslink.easiestdemo.wsoui.provided.Exchange;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIService;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;
import javax.xml.ws.WebServiceFeature;
import javax.xml.ws.Service;

@WebServiceClient(
	wsdlLocation = "crisis/v3/OfficeOfInfrastructure.wsdl",
	targetNamespace = "http://www.petalslink.org/OfficeOfInfrastructure/",
	name = "OfficeOfInfrastructureEventProducer")
public class OfficeOfInfrastructureEventProducer_WSOUIService extends Service implements WSOUIService{

	private static URL WSDL_LOCATION;
	public final static QName SERVICE = new QName("http://www.petalslink.org/OfficeOfInfrastructure/", "OfficeOfInfrastructureEventProducer");
	public final static QName OfficeOfInfrastructureEventProducersSOAPEndpoint = new QName("http://www.petalslink.org/OfficeOfInfrastructure/", "OfficeOfInfrastructureEventProducer");
	
	public static URL getWSDL_LOCATION() {
	  if(WSDL_LOCATION == null) {
	    WSDL_LOCATION = Thread.currentThread().getContextClassLoader().getResource("crisis/v3/OfficeOfInfrastructure.wsdl");
	    if(WSDL_LOCATION == null) {
	       throw new RuntimeException("Impossible to find wsdl in class loader at: crisis/v3/OfficeOfInfrastructure.wsdl");
	    } else {
	       System.out.println("WSDL localized at: " + WSDL_LOCATION + "");
	    }
	  }
	  return WSDL_LOCATION;
	}
	public OfficeOfInfrastructureEventProducer_WSOUIService() {
		super(getWSDL_LOCATION(), SERVICE);
	}

	@WebEndpoint(name = "OfficeOfInfrastructureEventProducersSOAPEndpoint")
	public NotificationProducer getOfficeOfInfrastructureEventProducersSOAPEndpoint() {
	    return super.getPort(OfficeOfInfrastructureEventProducersSOAPEndpoint, NotificationProducer.class);
	}
	
	
	@WebEndpoint(name = "OfficeOfInfrastructureEventProducersSOAPEndpoint")
	public NotificationProducer getFiremenSOAP(WebServiceFeature... features) {
	    return super.getPort(OfficeOfInfrastructureEventProducersSOAPEndpoint, NotificationProducer.class, features);
	}
	
	
	public URL getWsdlLocation() {
	    return WSDL_LOCATION;
	}

}

==> crisis-management-resources-v0.4-sources.jar: org/petalslink/officeofinfrastructure/OfficeOfInfrastructureEventProducer_WSOUIService.java <==
package org.petalslink.officeofinfrastructure;

import com.petalslink.wsn.service.wsnproducer.NotificationProducer;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.AbstractExchangeProcessor;
import org.petalslink.easiestdemo.wsoui.provided.Exchange;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIService;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;
import javax.xml.ws.WebServiceFeature;
import javax.xml.ws.Service;

@WebServiceClient(
	wsdlLocation = "crisis/management/generated/OfficeOfInfrastructure.wsdl",
	targetNamespace = "http://www.petalslink.org/OfficeOfInfrastructure/",
	name = "OfficeOfInfrastructureEventProducer")
public class OfficeOfInfrastructureEventProducer_WSOUIService extends Service implements WSOUIService{

	private static URL WSDL_LOCATION;
	public final static QName SERVICE = new QName("http://www.petalslink.org/OfficeOfInfrastructure/", "OfficeOfInfrastructureEventProducer");
	public final static QName OfficeOfInfrastructureEventProducersSOAPEndpoint = new QName("http://www.petalslink.org/OfficeOfInfrastructure/", "OfficeOfInfrastructureEventProducer");
	
	public static URL getWSDL_LOCATION() {
	  if(WSDL_LOCATION == null) {
	    WSDL_LOCATION = Thread.currentThread().getContextClassLoader().getResource("crisis/management/generated/OfficeOfInfrastructure.wsdl");
	    if(WSDL_LOCATION == null) {
	       throw new RuntimeException("Impossible to find wsdl in class loader at: crisis/management/generated/OfficeOfInfrastructure.wsdl");
	    } else {
	       System.out.println("WSDL localized at: " + WSDL_LOCATION + "");
	    }
	  }
	  return WSDL_LOCATION;
	}
	public OfficeOfInfrastructureEventProducer_WSOUIService() {
		super(getWSDL_LOCATION(), SERVICE);
	}

	@WebEndpoint(name = "OfficeOfInfrastructureEventProducersSOAPEndpoint")
	public NotificationProducer getOfficeOfInfrastructureEventProducersSOAPEndpoint() {
	    return super.getPort(OfficeOfInfrastructureEventProducersSOAPEndpoint, NotificationProducer.class);
	}
	
	
	@WebEndpoint(name = "OfficeOfInfrastructureEventProducersSOAPEndpoint")
	public NotificationProducer getFiremenSOAP(WebServiceFeature... features) {
	    return super.getPort(OfficeOfInfrastructureEventProducersSOAPEndpoint, NotificationProducer.class, features);
	}
	
	
	public URL getWsdlLocation() {
	    return WSDL_LOCATION;
	}

}
